pub enum Password {
U8(Vec<u8>),
String(String),
}Expand description
An enum that is holding the value of the password inside by its type.
The original implementation of brc-dd/iron-webcrypto uses any incoming password in vector form as
the key directly without any salt. But when the password is in String format, we will
generate salt and create the key using pbkdf2 algorithm.
Variants